See [navio-builder](https://pypi.org/project/navio-builder) for details.
This fork exists only to get windows compatibility.

It is possible that the 0.3.0 version of `navio-builder` now supports windows again.

This fork has 3.12 support